@@ -3,7 +3,6 @@ package Text::Parts;
 use warnings;
 use strict;
 use Carp ();
-use Carp::Heavy ();
 use File::Spec ();
 
 sub new {
@@ -272,7 +271,7 @@ sub eof {
   $self->{end} <= tell($self->{fh}) ? 1 : 0;
 }
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 =head1 NAME
 
@@ -465,7 +464,7 @@ If you set max_num, only split number of max_num.
 
  my @parts = $s->split(num => 5, max_num => 2);
 
-This trys to split 5 parts, but only 2 parts are returned.
+This tries to split 5 parts, but only 2 parts are returned.
 This is useful to try to test a few parts of too many parts.
 
 =head2 eol
